==> jc-1.4.0.tar.gz: javax/print/event/PrintServiceAttributeEvent.h <==
// public class javax.print.event.PrintServiceAttributeEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 4c95768fb6372ef3 javax_print_event_PrintEvent
// @dep_class 2c7f0f299f78f9e javax_print_event_PrintServiceAttributeEvent

// header file dependencies
// @dep_header javax_print_event_PrintEvent

#include "javax/print/event/PrintEvent.h"

#ifndef _JC_javax_print_event_PrintServiceAttributeEvent_H_
#define _JC_javax_print_event_PrintServiceAttributeEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_PrintService$object;
struct _jc_javax_print_attribute_PrintServiceAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_event_PrintServiceAttributeEvent$sub_refs	_jc_javax_print_event_PrintServiceAttributeEvent$sub_refs;
typedef struct _jc_javax_print_event_PrintServiceAttributeEvent$sub_nonrefs	_jc_javax_print_event_PrintServiceAttributeEvent$sub_nonrefs;
typedef struct _jc_javax_print_event_PrintServiceAttributeEvent$refs	_jc_javax_print_event_PrintServiceAttributeEvent$refs;
typedef struct _jc_javax_print_event_PrintServiceAttributeEvent$nonrefs	_jc_javax_print_event_PrintServiceAttributeEvent$nonrefs;
typedef struct _jc_javax_print_event_PrintServiceAttributeEvent$object	_jc_javax_print_event_PrintServiceAttributeEvent$object;

typedef const struct _jc_javax_print_event_PrintServiceAttributeEvent$vmethods	_jc_javax_print_event_PrintServiceAttributeEvent$vmethods;
typedef const struct _jc_javax_print_event_PrintServiceAttributeEvent$vtable	_jc_javax_print_event_PrintServiceAttributeEvent$vtable;
typedef const struct _jc_javax_print_event_PrintServiceAttributeEvent$vtype	_jc_javax_print_event_PrintServiceAttributeEvent$vtype;

// Constructors
extern void _jc_javax_print_event_PrintServiceAttributeEvent$method$_init$304ebd6a99e2d2e1(_jc_env *, struct _jc_javax_print_event_PrintServiceAttributeEvent$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_javax_print_event_PrintServiceAttributeEvent$method$getAttributes$32f80f9df1f10763(_jc_env *, struct _jc_javax_print_event_PrintServiceAttributeEvent$object *);
extern struct _jc_object *_jc_javax_print_event_PrintServiceAttributeEvent$method$getPrintService$471c0616b606f503(_jc_env *, struct _jc_javax_print_event_PrintServiceAttributeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_event_PrintServiceAttributeEvent$method_info$getAttributes$32f80f9df1f10763;
extern _jc_method _jc_javax_print_event_PrintServiceAttributeEvent$method_info$getPrintService$471c0616b606f503;

// Virtual methods structure
struct _jc_javax_print_event_PrintServiceAttributeEvent$vmethods {
	struct _jc_object	*(*getAttributes$32f80f9df1f10763)(_jc_env *, struct _jc_javax_print_event_PrintServiceAttributeEvent$object *);
	struct _jc_object	*(*getPrintService$471c0616b606f503)(_jc_env *, struct _jc_javax_print_event_PrintServiceAttributeEvent$object *);
};

// Vtable
struct _jc_javax_print_event_PrintServiceAttributeEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_print_event_PrintEvent$vmethods	javax_print_event_PrintEvent;
	_jc_javax_print_event_PrintServiceAttributeEvent$vmethods	javax_print_event_PrintServiceAttributeEvent;
};

// Vtype
struct _jc_javax_print_event_PrintServiceAttributeEvent$vtype {
	_jc_type			type;
	_jc_javax_print_event_PrintServiceAttributeEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_event_PrintServiceAttributeEvent$sub_refs {
	struct _jc_object	*attributes;
};

// Reference instance fields (object)
struct _jc_javax_print_event_PrintServiceAttributeEvent$refs {
    _jc_javax_print_event_PrintServiceAttributeEvent$sub_refs	javax_print_event_PrintServiceAttributeEvent;
    _jc_javax_print_event_PrintEvent$sub_refs	javax_print_event_PrintEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_event_PrintServiceAttributeEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_event_PrintServiceAttributeEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_print_event_PrintEvent$sub_nonrefs	javax_print_event_PrintEvent;
    _jc_javax_print_event_PrintServiceAttributeEvent$sub_nonrefs	javax_print_event_PrintServiceAttributeEvent;
};

// Object instance structure
struct _jc_javax_print_event_PrintServiceAttributeEvent$object {
	_jc_javax_print_event_PrintServiceAttributeEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_event_PrintServiceAttributeEvent$vtype	*vtype;
	_jc_javax_print_event_PrintServiceAttributeEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_event_PrintServiceAttributeEvent$vtype _jc_javax_print_event_PrintServiceAttributeEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_event_PrintServiceAttributeEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_event_PrintServiceAttributeEvent$class_object;

#endif	/* _JC_javax_print_event_PrintServiceAttributeEvent_H_ */

==> jc-1.4.6.tar.gz: javax/print/event/PrintServiceAttributeEvent.h <==
// public class javax.print.event.PrintServiceAttributeEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 4c95768fb6372ef3 javax_print_event_PrintEvent
// @dep_class 2c7f0f299f78f9e javax_print_event_PrintServiceAttributeEvent

// header file dependencies
// @dep_header javax_print_event_PrintEvent

#include "javax/print/event/PrintEvent.h"

#ifndef _JC_javax_print_event_PrintServiceAttributeEvent_H_
#define _JC_javax_print_event_PrintServiceAttributeEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_PrintService$object;
struct _jc_javax_print_attribute_PrintServiceAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_event_PrintServiceAttributeEvent$sub_refs	_jc_javax_print_event_PrintServiceAttributeEvent$sub_refs;
typedef struct _jc_javax_print_event_PrintServiceAttributeEvent$sub_nonrefs	_jc_javax_print_event_PrintServiceAttributeEvent$sub_nonrefs;
typedef struct _jc_javax_print_event_PrintServiceAttributeEvent$refs	_jc_javax_print_event_PrintServiceAttributeEvent$refs;
typedef struct _jc_javax_print_event_PrintServiceAttributeEvent$nonrefs	_jc_javax_print_event_PrintServiceAttributeEvent$nonrefs;
typedef struct _jc_javax_print_event_PrintServiceAttributeEvent$object	_jc_javax_print_event_PrintServiceAttributeEvent$object;

typedef const struct _jc_javax_print_event_PrintServiceAttributeEvent$vmethods	_jc_javax_print_event_PrintServiceAttributeEvent$vmethods;
typedef const struct _jc_javax_print_event_PrintServiceAttributeEvent$vtable	_jc_javax_print_event_PrintServiceAttributeEvent$vtable;
typedef const struct _jc_javax_print_event_PrintServiceAttributeEvent$vtype	_jc_javax_print_event_PrintServiceAttributeEvent$vtype;

// Constructors
extern void _jc_javax_print_event_PrintServiceAttributeEvent$method$_init$304ebd6a99e2d2e1(_jc_env *, struct _jc_javax_print_event_PrintServiceAttributeEvent$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_print_event_PrintServiceAttributeEvent$method$getAttributes$32f80f9df1f10763(_jc_env *, struct _jc_javax_print_event_PrintServiceAttributeEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_print_event_PrintServiceAttributeEvent$method$getPrintService$471c0616b606f503(_jc_env *, struct _jc_javax_print_event_PrintServiceAttributeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_event_PrintServiceAttributeEvent$method_info$getAttributes$32f80f9df1f10763;
extern _jc_method _jc_javax_print_event_PrintServiceAttributeEvent$method_info$getPrintService$471c0616b606f503;

// Virtual methods structure
struct _jc_javax_print_event_PrintServiceAttributeEvent$vmethods {
	struct _jc_object	*(*getAttributes$32f80f9df1f10763)(_jc_env *, struct _jc_javax_print_event_PrintServiceAttributeEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPrintService$471c0616b606f503)(_jc_env *, struct _jc_javax_print_event_PrintServiceAttributeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_event_PrintServiceAttributeEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_print_event_PrintEvent$vmethods	javax_print_event_PrintEvent;
	_jc_javax_print_event_PrintServiceAttributeEvent$vmethods	javax_print_event_PrintServiceAttributeEvent;
};

// Vtype
struct _jc_javax_print_event_PrintServiceAttributeEvent$vtype {
	_jc_type			type;
	_jc_javax_print_event_PrintServiceAttributeEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_event_PrintServiceAttributeEvent$sub_refs {
	struct _jc_object	*attributes;
};

// Reference instance fields (object)
struct _jc_javax_print_event_PrintServiceAttributeEvent$refs {
    _jc_javax_print_event_PrintServiceAttributeEvent$sub_refs	javax_print_event_PrintServiceAttributeEvent;
    _jc_javax_print_event_PrintEvent$sub_refs	javax_print_event_PrintEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_event_PrintServiceAttributeEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_event_PrintServiceAttributeEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_print_event_PrintEvent$sub_nonrefs	javax_print_event_PrintEvent;
    _jc_javax_print_event_PrintServiceAttributeEvent$sub_nonrefs	javax_print_event_PrintServiceAttributeEvent;
};

// Object instance structure
struct _jc_javax_print_event_PrintServiceAttributeEvent$object {
	_jc_javax_print_event_PrintServiceAttributeEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_event_PrintServiceAttributeEvent$vtype	*vtype;
	_jc_javax_print_event_PrintServiceAttributeEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_event_PrintServiceAttributeEvent$vtype _jc_javax_print_event_PrintServiceAttributeEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_event_PrintServiceAttributeEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_event_PrintServiceAttributeEvent$class_object;

#endif	/* _JC_javax_print_event_PrintServiceAttributeEvent_H_ */
